
SEARCH_BASE_URL = 'https://ccapimqa.apimanagement.us21.hana.ondemand.com/v1/cc/DSMVendorsInboundServices/ZAcctSearchAndRetrieveSet'
                   
SEARCH_PAR = "InternetFunctionCode eq 'ACCTSRCH' and "

RETRIEVE_PAR = "InternetFunctionCode eq 'RETRACCT' and "

RESULT_LOOKUP = {
    'S': 'S - Successful - The call was successful, and the reply contains appropriate results.',
    'W': 'W - Warning - The call was successful, but a warning message was generated.',
    'U': 'U - Unsatisfactory - The call was not completed successfully and/or no result set has been returned.',
    'F': 'F - Failure - There was an unrecoverable program error.',
    'D': 'D - Disabled - The specific function requested is not available at this time.',
}


from setuptools import setup

VERSION = '0.0.15'
DESCRIPTION = 'Dominion API python wrapper'

setup(
    name='dvpOAuth',
    version=VERSION,    
    description=DESCRIPTION,
    url='https://github.com/achillis2/dvpOAuth',
    author='Ding Li',
    author_email='dingli@gmail.com',
    license='BSD 2-clause',
    packages=['dvpOAuth'],
    install_requires=['requests',
                      'urllib3',
                      'pytest'
                      ],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
)
